#!/bin/bash
# ImageMagick
SRC_URL=ftp://ftp.imagemagick.org/pub/ImageMagick

# JBIG-KIT implements a highly effective data compression algorithm
# for bi-level high-resolution images such as fax pages or scanned documents. 
# http://www.cl.cam.ac.uk/~mgk25/jbigkit/
JBIGKIT_SRC=http://www.cl.cam.ac.uk/~mgk25/download/jbigkit-2.0.tar.gz
#
REPO=http://zenwalk.pinguix.com/user-accounts/stillborn/imagemagick
#
# script: til <rob DOT til DOT freedman AT googlemail DOT com>
# packager: stillborn

CWD=`pwd`
TMP=${TMP:-$CWD/tmp}
set -e -u -x

src_ver=6.6.8-10
src_pkg=ImageMagick-$src_ver.tar.xz
pkg_ver=$(echo $src_ver|tr '-' '_')
pkg_bld=70.1

arch=i486
tune=i686

MYCFLAGS="-O2 -march=$arch -mtune=$tune"

# discard '-?.tar.xz'
pkgname=${src_pkg%-*}
package=imagemagick-$pkg_ver-$arch-$pkg_bld

# get src: 
wget -qNc $SRC_URL/$src_pkg
PKG_SRC="$REPO/build-ImageMagick.sh 
$SRC_URL/$src_pkg
$JBIGKIT_SRC"
#
echo "$PKG_SRC" > $CWD/$package.src
# --with-perl-options='INSTALL_BASE=/usr' --with-perl-options='INSTALLDIRS=vendor'
if [ -e /var/log/packages/$package ]; then
	perl_option="--with-perl --with-perl-options='INSTALLDIRS=site'"
elif [ -e /usr/bin/Magick-config ]; then
	echo "remove install ImageMagick first"
	exit 1
else
	perl_option='--without-perl'
fi

PKG=$TMP/$package
SRC=$TMP/$pkgname
(rm -fr $SRC $PKG)

mkdir -p $PKG/usr/{doc,src}/$pkgname
mkdir -p $SRC 

tar xf $CWD/$src_pkg --strip-components=1 -C $SRC
tar xf $CWD/${JBIGKIT_SRC##*/} -C $SRC

cd $SRC/jbigkit
sed -i "s:-O2:$MYCFLAGS:g" Makefile
make || exit 1
# docs
mkdir -p $PKG/usr/doc/$pkgname/jbigkit-2.0
cp -a ANNOUNCE CHANGES COPYING $PKG/usr/doc/$pkgname/jbigkit-2.0

cd pbmtools
#make test || exit 1
install -m755 -d $PKG/usr/{bin,man/{man1,man5}}
install -m755 -t $PKG/usr/bin 		pbmtojbg jbgtopbm
install -m644 -t $PKG/usr/man/man5 	pgm.5 pbm.5 
install -m644 -t $PKG/usr/man/man1 	pbmtojbg.1 jbgtopbm.1 

cd $SRC

# fix DEST location
sed -i 's@DATA_DIR}/doc@PREFIX_DIR}/doc@' configure.ac
sed -i 's/^docdir = \(.*\)$/docdir = $(DOCUMENTATION_PATH)/' Makefile.am
#autoconf
autoreconf -f -i

# helperline ./configure --help >$CWD/configure--help

PERL_MAKE_OPTIONS='INSTALL_BASE=/usr' \
CFLAGS="-O2 -march=$arch -mtune=$tune" \
CXXFLAGS="-O2 -march=$arch -mtune=$tune" \
CPPFLAGS="-I./jbigkit/libjbig" \
LDFLAGS="-L./jbigkit/libjbig" \
  ./configure \
   --prefix=/usr \
   --mandir=/usr/man \
   --with-modules=yes \
   --disable-static \
   --enable-shared  \
   --without-openexr \
   --without-djvu  $perl_option

#  --with-frozenpaths=no    --disable-installed 

# do not install ChangeLog,LICENSE,NEWS.txt in usr/share/ImageMagick..
sed -i "s/^doc_DATA/no_doc_DATA/" Makefile

make && make install DESTDIR=$PKG
#

# docs
cp -a AUTHORS.txt LICENSE NOTICE QuickStart.txt README.txt ChangeLog\
			$PKG/usr/doc/$pkgname
cd $PKG
# strip symbols
find usr/ -perm 555 | xargs -r chmod 755
find usr/ -type f -perm 444 | xargs -r chmod 644
find usr/ -type f | xargs file | grep "executable\|shared object" | grep ELF |\
	cut -f 1 -d :| xargs -r strip --strip-unneeded
	
# man pages
test -d usr/share/man/man3 && { \
	mv usr/share/man/man3 usr/man
	rm -fr usr/share/man
}
find usr/man -type f -iname '*.?' |xargs gzip -9

# slack description
mkdir -p install
#          |-----handy-ruler------------------------------------------------------|
cat <<EOF > install/slack-desc
imagemagick: ImageMagick (software suite to create,edit,compose bitmap images)
imagemagick: 
imagemagick: ImageMagick is a software suite to create, edit, and compose 
imagemagick: bitmap images. It can read, convert and write images in a variety of
imagemagick: formats (about 200) including GIF, JPEG, JBIG, JPEG-2000, PNG, PDF, 
imagemagick: PhotoCD, TIFF, and DPX. Use ImageMagick to translate, flip, mirror,
imagemagick: rotate, scale, shear and transform images, adjust image colors, 
imagemagick: apply various special effects, or draw text, lines, polygons,
imagemagick: ellipses and Bezier curves.
imagemagick:
EOF
# clone script
mkdir -p usr/src/$pkgname
cp $CWD/build-ImageMagick.sh usr/src/$pkgname

find usr/ -name 'Magick.bs' -delete
find usr/ -name '.packlist' -delete
find usr/ -name 'perllocal.pod' -delete
find usr/ -type d -empty -delete
find usr/ -type f -iname '*.la' | xargs -r chmod 644

find usr/lib/ -iname '*.la' |xargs -n1 grep -l jbig \
| while read i; 
	do 	sed -i -e "s@-L$SRC/jbigkit/libjbig@@g" -e "s@-ljbig@@g" $i
	done

# helperline
(cd $PKG;find usr -printf "%y %m %u:%g %p %l\n" >$CWD/installed.files)

/sbin/makepkg -l y -c n $CWD/$package.txz
cd $CWD

PKG_DEP="bzip2,cairo,cxxlibs|gcc-g++,expat,fftw,fontconfig,freetype,gcc,glib2,gtk+2,jasper,lcms,libICE,libSM,libX11,libXau,libXdmcp,libXext,libXrender,libXt,libgsf,libjpeg,libpng,librsvg,libtiff,libtool,libwmf,libxcb,libxml2,pango,pixman,util-linux-ng,zlib"
echo -n $PKG_DEP >$package.dep
# depfinder $PKG >$package.dep
md5sum $package.txz >$package.md5


exit
mkdir -p script
cat <<EOF | xargs -n1 -i wget -N -P script http://www.imagemagick.org{}
/script/../source/coder.xml
/script/../source/colors.xml
/script/../source/configure.xml
/script/../source/delegates.xml
/script/../source/english.xml
/script/../source/francais.xml
/script/../source/locale.xml
/script/../source/log.xml
/script/../source/magic.xml
/script/../source/mime.xml
/script/../source/policy.xml
/script/../source/thresholds.xml
/script/../source/type.xml
/script/../source/type-ghostscript.xml
/script/../source/type-windows.xml
EOF


